<?php
namespace OrganizationsManagement\Controller;
use Zeedhi\Framework\Controller\Simple;
use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\Messages;

class Produto extends Simple
{
    /** @var Service\Produto $serviceProduto */
    protected $serviceProduto;

    public function __construct(Service\Produto $serviceProduto){
        $this->serviceProduto = $serviceProduto;
    }

    public function obtemTodos(DTO\Request\Filter $requisicao, DTO\Response $resposta){
        try{
            $page = $requisicao->getFilterCriteria()->getPage();
            $pageSize = $requisicao->getFilterCriteria()->getPageSize();
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $produtos = $this->serviceProduto->obtemTodos($filters, $page, $pageSize);
            $resposta->addDataSet(new DataSource\DataSet('products', $produtos));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Houve um erro ao buscar os produtos."));
        }
    }

    public function getProductRelationship(DTO\Request\Filter $requisicao, DTO\Response $resposta){
        try{
            $page = $requisicao->getFilterCriteria()->getPage();
            $pageSize = $requisicao->getFilterCriteria()->getPageSize();
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $productIds = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_ID', true);
            if($productIds){
                $columnName = (Utilities::getValueInFilterDataSourceByName($filters, 'TYPE_ID', false) == "S") ? "PRODUCT_ID_S" : "PRODUCT_ID_I";
                array_push($filters,array("columnName" => $columnName, "operator" => "IN", "value" => $productIds));
            }
            $produtos = $this->serviceProduto->getProductRelationship($filters, $page, $pageSize);
            $resposta->addDataSet(new DataSource\DataSet('getProductRelationship', $produtos));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Error"));
        }
    }

    public function saveProductRelationship(DTO\Request\DataSet $requisicao, DTO\Response $resposta){
        try {
            $produto = $requisicao->getDataSet()->getRows()[0];
            $cdproduto = $produto["ID"];
           
            $projectId = !empty($produto["PRODUCT_ID_I"]) ? $produto["PRODUCT_ID_I"] : null;
            $cdProdcomp = !empty($produto["PRODUCT_ID_S"]) ? $produto["PRODUCT_ID_S"] : null;
            $cdProdgrup = !empty($produto["PRODUCT_TYPE_ID"]) ? $produto["PRODUCT_TYPE_ID"] : null;
            
            $this->serviceProduto->saveProductRelationship($cdproduto,$projectId,$cdProdcomp,$cdProdgrup);
            $resposta->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
        } catch(\Exception $ex){
            $resposta->addMessage(new DTO\Response\Message($ex->getMessage()));            
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findProductCallProducts(DTO\Request\Filter $requisicao, DTO\Response $resposta){
        try{
            $page = $requisicao->getFilterCriteria()->getPage();
            $pageSize = $requisicao->getFilterCriteria()->getPageSize();
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $produtos = $this->serviceProduto->findProductCallProducts($filters, $page, $pageSize);
            $resposta->addDataSet(new DataSource\DataSet('findProductCallProducts', $produtos));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Error"));
        }
    }

    public function findProductCallProductsFromRichClient(DTO\Request\Filter $requisicao, DTO\Response $resposta){
        try{
            $page = $requisicao->getFilterCriteria()->getPage();
            $pageSize = $requisicao->getFilterCriteria()->getPageSize();
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $productType = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_TYPE', true);
            $produtos = $this->serviceProduto->findProductCallProductsFromRichClient($filters, $page, $pageSize,$productType);
            $resposta->addDataSet(new DataSource\DataSet('findProductCallProductsFromRichClient', $produtos));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Error"));
        }
    }

    public function findProductCallProductTypes(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $productCallProducTypes = $this->serviceProduto->findProductCallProductTypes($filters);
            $response->addDataSet(new DataSet('findProductCallProductTypes', $productCallProducTypes));
        } catch(\Exception $e) {
            $response->addDataSet(new DataSet('findProductCallProductTypes', array()));
        }
    }
    
    public function getProduct(DTO\Request\Filter $request, DTO\Response $response){
        try{
            $productId = $request->getFilterCriteria()->getConditions()[0]["value"];
            $product = $this->serviceProduto->findProduct($productId);
            $response->addDataSet(new DataSource\DataSet('product', $product));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message("Houve um erro ao buscar o produto."));
        }
    }
    
    public function save(DTO\Request\DataSet $requisicao, DTO\Response $resposta){
        try {
            $produto = $requisicao->getDataSet()->getRows()[0];
            $id = $produto["ID"];
            $idStatus = $produto["IDSTATUS"];
            $dsurlJsonMenu = $produto["DSURL_JSON_MENU"];
            $dschavenotif = $produto["DSCHAVENOTIF"];
            $cdappnotif = $produto["CDAPPNOTIF"];
            $idprodutosaas = $produto["IDPRODUTOSAAS"];
            $idpercriarchamadas = $produto["IDPERCRIARCHAMADO"];
            $idperdeploy = $produto["IDPERDEPLOY"];
            $idProdutoAssistant = $produto["IDPRODUTOASSISTANT"];
            $idUtAssMultVer = $produto["IDUTASSMULTVER"];

            $this->serviceProduto->save($id, $dsurlJsonMenu, $idStatus, $dschavenotif, $cdappnotif, $idprodutosaas, $idpercriarchamadas, $idperdeploy,
                $idProdutoAssistant, $idUtAssMultVer);
            $resposta->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
        } catch(\Exception $ex){
            $resposta->addMessage(new DTO\Response\Message($ex->getMessage()));            
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function synchronize(DTO\Request\Filter $requisicao, DTO\Response $resposta){
        try {
            $this->serviceProduto->synchronize();
            $resposta->addMessage(new DTO\Response\Message("Sincronizado com sucesso!"));
        } catch(\Exception $ex){
            throw $ex;
        }
    }

    public function obtemProdutosPorOrganizacao(DTO\Request\Filter $requisicao, DTO\Response $resposta) {
        
        try{
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $organizationId = $filters[0]['value'];
            unset($filters[0]);
            $produtosOrganizacao = $this->serviceProduto->obtemProdutosOrganizacao($organizationId, $filters);
            $resposta->addDataSet(new DataSource\DataSet('organizationProducts', $produtosOrganizacao));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Houve um erro ao buscar os produtos da organização."));
        }
    }

    public function organizationProductsCreateNewIfNotExists(DTO\Request\Filter $requisicao, DTO\Response $resposta) {
        try{
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $nrorg = Utilities::getValueInFilterDataSourceByName($filters, 'NRORG_ID', true);
            $nrProduto = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', false);
            $produtosOrganizacao = $this->serviceProduto->obtemProdutosOrganizacao($nrorg, $filters);
            if(!$produtosOrganizacao){
                $produtosOrganizacao = $this->serviceProduto->createNewProductOrg($nrorg, $filters, $nrProduto);
            }
            $resposta->addDataSet(new DataSource\DataSet('organizationProducts', $produtosOrganizacao));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Houve um erro ao buscar os produtos da organização."));
        }
    }

    public function obtemProdutosPorOrganizacaoNaoIncluidos(DTO\Request\Filter $requisicao, DTO\Response $resposta) {
        try{
            $filters = $requisicao->getFilterCriteria()->getConditions();
            $organizationId = $filters[0]['value'];
            unset($filters[0]);
            $produtosOrganizacao = $this->serviceProduto->obtemProdutosPorOrganizacaoNaoIncluidos($organizationId, $filters);
            $resposta->addDataSet(new DataSource\DataSet('organizationProducts', $produtosOrganizacao));
        } catch(\Exception $ex){
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $resposta->addMessage(new DTO\Response\Message("Houve um erro ao buscar os produtos da organização."));
        }
    }

    public function saveOrganizationProducts(DTO\Request\DataSet $requisicao, DTO\Response $resposta){
        try {
            $requestRow = $requisicao->getDataSet()->getRows()[0];
            $produtosOrg = $requestRow['PRODUTOS_ORG'];
            $this->serviceProduto->saveOrganizationProducts($produtosOrg);
            $resposta->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
            $resposta->addDataSet(new DataSource\DataSet('successProdutosOrg', array(true)));
        } catch(\Exception $ex){
            $resposta->addMessage(new DTO\Response\Message($ex->getMessage()));            
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function removeProdutoPorOrganizacao(DTO\Request\Row $requisicao, DTO\Response $resposta){
        try {
            $requestRow = $requisicao->getRow();
            $id = $requestRow['ID'];
            $this->serviceProduto->removeProdutoPorOrganizacao($id);
            $resposta->addMessage(new DTO\Response\Message(Messages::SUC_REMOVED_SIMPLE));
            $resposta->addDataSet(new DataSource\DataSet('removedProdutoOrg', array($id)));
        } catch(\Exception $ex){
            $resposta->addMessage(new DTO\Response\Message($ex->getMessage()));            
            $resposta->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }
    
    public function saveMenuElements(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $urlJsonFile = $requestRow['urlJsonFile'];
            $productId = $requestRow['productId'];
            $objJson = $this->serviceProduto->saveMenuElements($urlJsonFile, $productId);
            $response->addDataSet(new DataSource\DataSet('json', $objJson));
        } catch(\Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
        }
    }
    
    public function saveProductAppCode(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $cdappnotif = $requestRow['CDAPPNOTIF'];
            $dschavenotif = $requestRow['DSCHAVENOTIF'];
            $productId = $requestRow['ID'];
            $idProdSaas = $requestRow['IDPRODUTOSAAS'];
            $dataSet = $this->serviceProduto->saveProductAppCode($dschavenotif, $cdappnotif, $productId, $idProdSaas);
            $response->addDataSet(new DataSet ('product', $dataSet));
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findProductRepositories(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters     = $request->getFilterCriteria()->getConditions();
            $nrProdutoId = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers   = $this->serviceProduto->findProductRepositories($filters, $nrProdutoId);
            $response->addDataSet(new DataSource\DataSet('productRepositories', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findNotInsertedProductRepositories(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters           = $request->getFilterCriteria()->getConditions();
            $externalProductId = Utilities::getValueInFilterDataSourceByName($filters, 'NREXTERNAL_PRODUCT_ID', true);
            $nrProdutoId       = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers         = $this->serviceProduto->findNotInsertedProductRepositories($filters,
                $externalProductId, $nrProdutoId);
            $response->addDataSet(new DataSource\DataSet('productRepositories', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveProductRepository(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id = $requestRow['ID'];
            $nrProdutoId = $requestRow['NRPRODUTO_ID'];
            $nrExternalRepositoryId = $requestRow['NREXTERNAL_REPOSITORY_ID'];
            $dsdirrelmigdb = $requestRow['DSDIRRELMIGBD'];
            $idAtivo = $requestRow['IDATIVO'];
            $dataSet = $this->serviceProduto->saveProductRepository($id, $nrProdutoId, $nrExternalRepositoryId, $dsdirrelmigdb, $idAtivo);
            $response->addDataSet(new DataSet ('productRepository', $dataSet));
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function deleteProductRepository(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id = $requestRow['ID'];
            $this->serviceProduto->deleteProductRepository($id);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findVariableMeasurementSettings(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters     = $request->getFilterCriteria()->getConditions();
            $nrProdutoId = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers   = $this->serviceProduto->findVariableMeasurementSettings($filters, $nrProdutoId);
            $response->addDataSet(new DataSource\DataSet('variableMeasurementSettings', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveVariableMeasurementSettings(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow       = $request->getDataSet()->getRows()[0];
            $id               = $requestRow['ID'];
            $nrProdutoId      = $requestRow['NRPRODUTO_ID'];
            $phpScriptLog     = $requestRow['PHP_SCRIPT_LOG'];
            $phpScriptCount   = $requestRow['PHP_SCRIPT_COUNT'];
            $qtdDiasAviso     = $requestRow['QTD_DIAS_AVISO'];
            $qtdDiasReaplicar = $requestRow['QTD_DIAS_REAPLICAR'];
            $cdTpMedidaServ   = $requestRow['CDTPMEDIDASERV'];
            $idAtivo          = $requestRow['IDATIVO'];
            $nrprodutoIdRel   = $requestRow['NRPRODUTO_ID_REL'];
            $idTpScript       = $requestRow['IDTPSCRIPT'];
            $dataSet = $this->serviceProduto->saveVariableMeasurementSettings($id, $nrProdutoId, $phpScriptLog,
                $phpScriptCount, $qtdDiasAviso, $qtdDiasReaplicar, $cdTpMedidaServ, $idAtivo, $nrprodutoIdRel, $idTpScript);
            $response->addDataSet(new DataSet ('variableMeasurementSettings', $dataSet));
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function deleteVariableMeasurementSettings(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id = $requestRow['ID'];
            $this->serviceProduto->deleteVariableMeasurementSettings($id);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findTipoMedidaServ(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $page      = $request->getFilterCriteria()->getPage();
            $pageSize  = $request->getFilterCriteria()->getPageSize();
            $filters   = $request->getFilterCriteria()->getConditions();
            $registers = $this->serviceProduto->findTipoMedidaServ($filters, $page, $pageSize);
            $response->addDataSet(new DataSource\DataSet('tipoMedidaServ', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveTipoMedidaServ(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $requestRow           = $request->getDataSet()->getRows()[0];
            $cdTpMedidaServ       = $requestRow['CDTPMEDIDASERV'];
            $idTpColetaMedidaServ = $requestRow['IDTPCOLETAMEDIDASERV'];
            $dataSet              = $this->serviceProduto->saveTipoMedidaServ($cdTpMedidaServ, $idTpColetaMedidaServ);
            $response->addDataSet(new DataSet ('tipoMedidaServ', $dataSet));
        } catch (Exception $ex) {
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findCollectionVariableMeasures(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $conditions     = $request->getFilterCriteria()->getConditions();
            $dataSourceName = $request->getFilterCriteria()->getDataSourceName();
            $page           = $request->getFilterCriteria()->getPage();
            $pageSize       = $request->getFilterCriteria()->getPageSize();
            $orderBy        = $request->getFilterCriteria()->getOrderBy();
            $nrProdutoId    = Utilities::getValueInFilterDataSourceByName($conditions, 'NRPRODUTO_ID', true);
            $nrOrgId        = Utilities::getValueInFilterDataSourceByName($conditions, 'NRORG_ID', true);
            $registers      = $this->serviceProduto->findCollectionVariableMeasures($conditions, $dataSourceName,
                $page, $pageSize, $orderBy, $nrProdutoId, $nrOrgId);
            $response->addDataSet(new DataSource\DataSet('collectionVariableMeasurement', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findCollectionGeneral(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $conditions     = $request->getFilterCriteria()->getConditions();
            $dataSourceName = $request->getFilterCriteria()->getDataSourceName();
            $page           = $request->getFilterCriteria()->getPage();
            $pageSize       = $request->getFilterCriteria()->getPageSize();
            $orderBy        = $request->getFilterCriteria()->getOrderBy();
            $nrProdutoId    = Utilities::getValueInFilterDataSourceByName($conditions, 'NRPRODUTO_ID', true);
            $nrOrgId        = Utilities::getValueInFilterDataSourceByName($conditions, 'NRORG_ID', true);
            $registers      = $this->serviceProduto->findCollectionGeneral($conditions, $dataSourceName,
                $page, $pageSize, $orderBy, $nrProdutoId, $nrOrgId);
            $response->addDataSet(new DataSource\DataSet('generalCollect', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findProductAvailableVersions(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters        = $request->getFilterCriteria()->getConditions();
            $nrProdutoId = Utilities::getValueInFilterDataSourceByName($filters, 'NREXTERNAL_PRODUCT_ID', true);
            $nrorgId = Utilities::getValueInFilterDataSourceByName($filters, 'NRORG_ID', true);
            $nrProduto = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers      = $this->serviceProduto->findProductAvailableVersions($nrProdutoId, $nrorgId, $nrProduto, $filters);
            $response->addDataSet(new DataSource\DataSet('availableVersions', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findProductAvailableLatestVersions(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters        = $request->getFilterCriteria()->getConditions();
            $nrProdutoOrgId = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_ORG', true);
            $registers      = $this->serviceProduto->findProductAvailableLatestVersions($nrProdutoOrgId, $filters);
            $response->addDataSet(new DataSource\DataSet('modulesConfiguration', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveProductAvailableVersions(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            $this->serviceProduto->saveLTSVersions($rows);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function deleteProductAvailableVersions(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $this->serviceProduto->deleteProductAvailableVersions($requestRow);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findLTSVersions(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters         = $request->getFilterCriteria()->getConditions();
            $page            = $request->getFilterCriteria()->getPage();
            $pageSize        = $request->getFilterCriteria()->getPageSize();
            $nrProdutoId     = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $notInsertedOnly = Utilities::getValueInFilterDataSourceByName($filters, 'NOT_INSERTED_ONLY', true);
            $productOrgId    = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ORG_ID', true);
            $registers       = $this->serviceProduto->findLTSVersions($filters, $nrProdutoId, $page, $pageSize, $notInsertedOnly, $productOrgId);
            $response->addDataSet(new DataSource\DataSet('availableVersions', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findLTSVersionsByDevopsId(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters         = $request->getFilterCriteria()->getConditions();
            $page            = $request->getFilterCriteria()->getPage();
            $pageSize        = $request->getFilterCriteria()->getPageSize();
            $devopsId     = Utilities::getValueInFilterDataSourceByName($filters, 'DEVOPS_ID', true);
            $notInsertedOnly = Utilities::getValueInFilterDataSourceByName($filters, 'NOT_INSERTED_ONLY', true);
            $productOrgId    = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ORG_ID', true);
            $registers       = $this->serviceProduto->findLTSVersionsByDevopsId($filters, $devopsId, $page, $pageSize, $notInsertedOnly, $productOrgId);
            $response->addDataSet(new DataSource\DataSet('availableVersions', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveLTSVersions(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            $this->serviceProduto->saveLTSVersions($rows);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function saveLTSVersionsByDevopsId(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            $this->serviceProduto->saveLTSVersionsByDevopsId($rows);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findVersionModulesConfiguration(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters          = $request->getFilterCriteria()->getConditions();
            $productVersionId = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_VERSION_ID', true);
            $registers        = $this->serviceProduto->findVersionModulesConfiguration($filters, $productVersionId);
            $response->addDataSet(new DataSource\DataSet('modulesConfiguration', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveProductLineParams(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow       = $request->getDataSet()->getRows()[0];
            $id               = $requestRow['ID'];
            $dsLinhaProduto   = $requestRow['DSLINHAPRODUTO'];
            $idTpLinhaProduto = $requestRow['IDTPLINHAPRODUTO'];
            $idModoProc       = $requestRow['IDMODOPROC'];
            $cdTpMedidaServ   = $requestRow['CDTPMEDIDASERV'];
            $cdusuTpMedidaServ  = !empty($requestRow["CDUSUTPMEDIDASERV"]) ? $requestRow["CDUSUTPMEDIDASERV"] : null;
            $this->serviceProduto->saveProductLineParams($id, $dsLinhaProduto, $idTpLinhaProduto, $idModoProc, $cdTpMedidaServ, $cdusuTpMedidaServ);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function saveSystemProductLineParams(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id         = $requestRow['ID'];
            $cdSistema  = $requestRow['CDSISTEMA'];
            $this->serviceProduto->saveSystemProductLineParams($id, $cdSistema);
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function systemProductLine(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $filters          = $request->getFilterCriteria()->getConditions();
            $idTpLinhaProduto = Utilities::getValueInFilterDataSourceByName($filters, 'IDTPLINHAPRODUTO', true);
            $registers        = $this->serviceProduto->getSystemProductLine($filters, $idTpLinhaProduto);
            $response->addDataSet(new DataSource\DataSet('systemProductLine', $registers));
        } catch (\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findCollectSettings(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $cdtpmedidaserv = Utilities::getValueInFilterDataSourceByName($filters, 'CDTPMEDIDASERV', true);
            $registers = $this->serviceProduto->findCollectSettings($cdtpmedidaserv, $filters);
            $response->addDataSet(new DataSource\DataSet('collectSettings', $registers));
        } catch(\Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveCollectSettings(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try {
            $row              = $request->getDataSet()->getRows()[0];
            $id               = $row['ID'] ? $row['ID'] : null;
            $cdtpmedidaserv   = $row['CDTPMEDIDASERV'];
            $qtddiasaviso     = $row['QTD_DIAS_AVISO'];
            $qtddiasreaplicar = $row['QTD_DIAS_REAPLICAR'];
            $idativo          = $row['IDATIVO'];
            $phpscriptcount   = $row['PHP_SCRIPT_COUNT'];
            $phpscriptlog     = $row['PHP_SCRIPT_LOG'];
            $cdservorca       = $row['CDSERVORCA'];
            $idTpScript       = $row['IDTPSCRIPT'];

            $dataSet = $this->serviceProduto->saveCollectSettings($id, $cdtpmedidaserv, $qtddiasaviso, $qtddiasreaplicar, 
                $idativo, $phpscriptcount, $phpscriptlog, $cdservorca, $idTpScript);
            $response->addMessage(new DTO\Response\Message(Messages::SUC_SAVED));
            $response->addDataSet(new DataSet ('saveCollectSettings', $dataSet));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function deleteCollectSettings(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id = $requestRow['ID'];
            $this->serviceProduto->deleteCollectSettings($id);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function findTiposervicoorca(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $conditions     = $request->getFilterCriteria()->getConditions();
            $data           = $this->serviceProduto->findTiposervicoorca($conditions);
            $response->addDataSet(new DataSource\DataSet('tiposervicoorca', $data));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findConfigColeta(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters        = $request->getFilterCriteria()->getConditions();
            $nrProdutoId = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers      = $this->serviceProduto->findConfigColeta($filters, $nrProdutoId);
            $response->addDataSet(new DataSource\DataSet('availableVersions', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    /**
     * @param DTO\Request\DataSet $request
     * @param DTO\Response $response
     * @throws \Exception
     */
    public function saveConfigColeta(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try {
            $row = $request->getDataSet()->getRows()[0];
            $id = isset($row['ID']) ? $row['ID'] : null;
            $idAtivo = $row['IDATIVO'];
            $qtdDiasReaplicar = $row['QTD_DIAS_REAPLICAR'];
            $dtLimite = $row['DT_LIMITE'];
            $phpScriptLog = $row['PHP_SCRIPT_LOG'];
            $nrproductoId = $row['NRPRODUTO_ID'];
            $nrorgIds = $row['NRORG_ID'];
            $dataSet = $this->serviceProduto->saveConfigColeta($id, $idAtivo, $qtdDiasReaplicar, $dtLimite, $phpScriptLog, $nrproductoId, $nrorgIds);
            $response->addDataSet(new DataSet ('configColeta', $dataSet));
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function deleteConfigColeta(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $requestRow = $request->getDataSet()->getRows()[0];
            $id = $requestRow['ID'];
            $this->serviceProduto->deleteConfigColeta($id);
        } catch (Exception $ex) {
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), 500));
        }
    }

    public function validateVariableMeasureSettings(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters        = $request->getFilterCriteria()->getConditions();
            $nrProdutoId    = Utilities::getValueInFilterDataSourceByName($filters, 'PRODUCT_ID', true);
            $organizationId = Utilities::getValueInFilterDataSourceByName($filters, 'ORGANIZATION_ID', true);
            $validation     = $this->serviceProduto->validateVariableMeasureSettings($nrProdutoId, $organizationId);
            $response->addDataSet(new DataSource\DataSet('validation', array($validation)));
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function getProductCollector(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters     = $request->getFilterCriteria()->getConditions();
            $nrProdutoId = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ID', true);
            $registers   = $this->serviceProduto->getProductCollector($filters, $nrProdutoId);
            $response->addDataSet(new DataSource\DataSet('productCollector', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveProductCollector(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row             = $request->getDataSet()->getRows()[0];
            $id              = isset($row['ID']) ? $row['ID'] : null;
            $idativo         = $row['IDATIVO'];
            $nrProdutoId     = $row['NRPRODUTO_ID'];
            $idColetor       = empty($row['IDCOLETOR'])       ? null : $row['IDCOLETOR'];
            $dsStringConexao = empty($row['DSSTRINGCONEXAO']) ? null : $row['DSSTRINGCONEXAO'];
            $idUtWallet      = empty($row['IDUTWALLET'])      ? null : $row['IDUTWALLET'];
            $dsUsuarioBanco  = empty($row['DSUSUARIOBANCO'])  ? null : $row['DSUSUARIOBANCO'];
            $dsSenhaBanco    = empty($row['DSSENHABANCO'])    ? null : $row['DSSENHABANCO'];
            $idTpBanco       = empty($row['IDTPBANCO'])       ? 'ORACLE' : $row['IDTPBANCO'];
            $saveParameters  = $this->serviceProduto->saveProductCollector($id,  $idColetor,
                $dsStringConexao, $idUtWallet, $dsUsuarioBanco, $dsSenhaBanco, $idativo, $nrProdutoId, $idTpBanco);
            $response->addDataSet(new DataSource\DataSet('savedCollector', $saveParameters));
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function removeProductCollector(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
            $id  = isset($row['ID']) ? $row['ID'] : null;
            $this->serviceProduto->removeProductCollector($id);
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function getProductOrgCollector(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $filters        = $request->getFilterCriteria()->getConditions();
            $nrProdutoOrgId = Utilities::getValueInFilterDataSourceByName($filters, 'NRPRODUTO_ORG_ID', true);
            $registers      = $this->serviceProduto->getProductOrgCollector($filters, $nrProdutoOrgId);
            $response->addDataSet(new DataSource\DataSet('productCollector', $registers));
        } catch(\Exception $ex){
            $response->addMessage(new DTO\Response\Message($ex->getMessage()));
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveProductOrgCollector(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row             = $request->getDataSet()->getRows()[0];
            $id              = isset($row['ID']) ? $row['ID'] : null;
            $idativo         = $row['IDATIVO'];
            $nrProdutoOrgId  = $row['NRPRODUTO_ORG_ID'];
            $idColetor       = empty($row['IDCOLETOR'])       ? null : $row['IDCOLETOR'];
            $dsStringConexao = empty($row['DSSTRINGCONEXAO']) ? null : $row['DSSTRINGCONEXAO'];
            $idUtWallet      = empty($row['IDUTWALLET'])      ? null : $row['IDUTWALLET'];
            $dsUsuarioBanco  = empty($row['DSUSUARIOBANCO'])  ? null : $row['DSUSUARIOBANCO'];
            $dsSenhaBanco    = empty($row['DSSENHABANCO'])    ? null : $row['DSSENHABANCO'];
            $idTpBanco       = empty($row['IDTPBANCO'])       ? 'ORACLE' : $row['IDTPBANCO'];
            $saveParameters  = $this->serviceProduto->saveProductOrgCollector($id,  $idColetor,
                $dsStringConexao, $idUtWallet, $dsUsuarioBanco, $dsSenhaBanco, $idativo, $nrProdutoOrgId, $idTpBanco);
            $response->addDataSet(new DataSource\DataSet('savedCollector', $saveParameters));
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function removeProductOrgCollector(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $row = $request->getDataSet()->getRows()[0];
            $id  = isset($row['ID']) ? $row['ID'] : null;
            $this->serviceProduto->removeProductOrgCollector($id);
        } catch(\Exception $ex){
            $response->setError(new DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}